@@ -1,5 +1,14 @@
 library(vroom)
-x <- vroom(file, id = "path", col_types = c(pickup_datetime = "c"), trim_ws = FALSE, quote = "", escape_double = FALSE, na = character(), altrep = TRUE)
+x <- vroom(
+  file,
+  id = "path",
+  col_types = c(pickup_datetime = "c"),
+  trim_ws = FALSE,
+  quote = "",
+  escape_double = FALSE,
+  na = character(),
+  altrep = TRUE
+)
 print(head(x, 10))
 a <- head(x)
 b <- tail(x)
